
# Slot: located in


holds between a material entity and a material entity or site within which it is located (but of which it is not considered a part)

URI: [biolink:located_in](https://w3id.org/biolink/vocab/located_in)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0001025 |
|  | | FMA:has_location |
| **Narrow Mappings:** | | GOREL:0001004 |
|  | | BSPO:0000107 |
|  | | BSPO:0000108 |
|  | | BSPO:0000120 |
|  | | BSPO:0000121 |
|  | | BSPO:0000122 |
|  | | BSPO:0000123 |
|  | | BSPO:0000124 |
|  | | BSPO:0000125 |
|  | | BSPO:0000126 |
|  | | BSPO:0001100 |
|  | | BSPO:0001101 |
|  | | BSPO:0001107 |
|  | | BSPO:0015101 |
|  | | BSPO:0015102 |
|  | | BSPO:0015202 |
|  | | UBERON_CORE:in_central_side_of |
|  | | UBERON_CORE:in_innermost_side_of |
|  | | UBERON_CORE:in_outermost_side_of |
|  | | NCIT:R100 |
|  | | EFO:0000784 |
|  | | FMA:has_location |
|  | | HMDB:at_cellular_location |
|  | | HMDB:at_tissue |
|  | | HMDB:in_biospecimen |
|  | | LOINC:has_imaging_focus |
|  | | NCIT:R156 |
|  | | NCIT:R155 |
|  | | NCIT:R145 |
|  | | NCIT:R40 |
|  | | NCIT:is_location_of_anatomic_structure |
|  | | NCIT:R171 |
|  | | NCIT:R167 |
|  | | NCIT:R165 |
|  | | NCIT:R169 |
|  | | NCIT:R170 |
|  | | NCIT:R166 |
|  | | NCIT:R168 |
|  | | RO:0002303 |
|  | | RTXKG1:disease_has_location |
|  | | SNOMED:has_finding_site |
|  | | SNOMED:has_indirect_procedure_site |
|  | | SNOMED:has_inherent_location |

